@@ -37,13 +37,14 @@ try {
                         sc.container_id,
                         s.site_name,
                         s.username,
-                        d.domain_name as primary_domain,
+                        COALESCE(sd.fqdn, d.domain_name) as primary_domain,
                         ct.name as container_type
                     FROM whp.site_containers sc
                     JOIN whp.sites s ON sc.site_id = s.id
                     JOIN whp.domains d ON s.primary_domain_id = d.id
+                    LEFT JOIN whp.site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                     JOIN whp.container_types ct ON s.container_type_id = ct.id
-                    WHERE sc.status = 'running'
+                    WHERE sc.status IN ('running', 'active')
                     ORDER BY s.username, s.site_name, sc.container_number
                 ");
             } else {
@@ -53,13 +54,14 @@ try {
                         sc.container_id,
                         s.site_name,
                         s.username,
-                        d.domain_name as primary_domain,
+                        COALESCE(sd.fqdn, d.domain_name) as primary_domain,
                         ct.name as container_type
                     FROM whp.site_containers sc
                     JOIN whp.sites s ON sc.site_id = s.id
                     JOIN whp.domains d ON s.primary_domain_id = d.id
+                    LEFT JOIN whp.site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                     JOIN whp.container_types ct ON s.container_type_id = ct.id
-                    WHERE sc.status = 'running' AND s.username = ?
+                    WHERE sc.status IN ('running', 'active') AND s.username = ?
                     ORDER BY s.site_name, sc.container_number
                 ");
                 $stmt->execute([AUTH_USER]);
