@@ -487,7 +487,7 @@ class haproxy_manager {
                 JOIN whp.domains d ON s.primary_domain_id = d.id
                 LEFT JOIN whp.site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                 JOIN whp.container_types ct ON s.container_type_id = ct.id
-                WHERE sc.site_id = ? AND sc.status = 'active'
+                WHERE sc.site_id = ? AND (sc.status = 'active' OR sc.status = 'running')
             ");
             $stmt->execute([$site_id]);
             $containers = $stmt->fetchAll();
